@@ -8,7 +8,7 @@ library(survey)
 
 input_data <- data.frame(tch = round(rnorm(n = 250, mean = 8, sd = 0.5), digits = 2),
                          ch = round(rnorm(n = 250, mean = 13, sd = 0.5), digits = 2),
-                         ex = round(rnorm(n = 250, mean = 16, sd = 0.5), digits = 2),
+                         ex = round(rnorm(n = 250, mean = 15, sd = 1), digits = 2),
                          tex = round(rnorm(n = 250, mean = 20, sd = 0.5), digits = 2),
                          pi_cheap = sample(x = c(1:5), size = 250,
                                            replace = TRUE, prob = c(0.1, 0.1, 0.2, 0.3, 0.3)),
@@ -305,6 +305,14 @@ test_that("Data Output - Plausibility: If data is misbalanced, weighting should
   expect_gt(psm_results_w1$opp, psm_results_unw$opp)
 })
 
+#----
+# Structure of Output Object
+#----
+
+test_that("Ensuring that cases with invalid cases are removed", {
+  expect_equal(nrow(psm_results_w1$data_input), psm_results_w1$total_sample - psm_results_w1$invalid_cases)
+})
+
 # clean up workspace after test
 rm(input_data, input_data_2, input_design_1, input_design_2, psm_results_w1, psm_results_w2, psm_results_unw, psm_results_w3)
 
